<?php

class ADMINWIDGETS_CTRL_Admin extends ADMIN_CTRL_Abstract {

    public function __construct() {
        parent::__construct();

        if (OW::getRequest()->isAjax()) {
            return;
        }

        $menu = new BASE_CMP_ContentMenu();

        $menuItem = new BASE_MenuItem();
        $menuItem->setKey('links');
        $menuItem->setLabel(OW::getLanguage()->text('adminwidgets', 'admin_manage_links'));
        $menuItem->setUrl(OW::getRouter()->urlForRoute('adminwidgets_admin_links'));
        $menuItem->setIconClass('ow_ic_gear_wheel');
        $menuItem->setOrder(1);
        $menu->addElement($menuItem);

        $menuItem = new BASE_MenuItem();
        $menuItem->setKey('sections');
        $menuItem->setLabel(OW::getLanguage()->text('adminwidgets', 'admin_manage_sections'));
        $menuItem->setUrl(OW::getRouter()->urlForRoute('adminwidgets_admin_sections'));
        $menuItem->setIconClass('ow_ic_files');
        $menuItem->setOrder(2);
        $menu->addElement($menuItem);

        $this->addComponent('menu', $menu);
        $this->menu = $menu;

        $this->setPageHeading(OW::getLanguage()->text('adminwidgets', 'admin_settings_title'));
        $this->setPageHeadingIconClass('ow_ic_gear_wheel');
    }

    public function sections() {
        $allSections = ADMINWIDGETS_BOL_Service::getInstance()->getAllSections();
        $sectionDetails = array();

        foreach ($allSections as $section) {
            $sectionDetails[$section->id]['id'] = $section->id;
            $sectionDetails[$section->id]['secColumn'] = $section->section;
            $sectionDetails[$section->id]['secName'] = $section->name;

            $sectionDetails[$section->id]['editUrl'] = OW::getRouter()->urlForRoute('adminwidgets_admin_section_edit', array('id' => $section->id));
            $sectionDetails[$section->id]['deleteUrl'] = OW::getRouter()->urlFor(__CLASS__, 'deletesection', array('column' => $section->section));
        }
        $this->assign('allSections', $sectionDetails);

        $js = UTIL_JsGenerator::newInstance()
                ->newVariable('addNewLink', OW::getRouter()->urlForRoute('adminwidgets_admin_section_add'))
                ->jQueryEvent('#btn-add-new-link', 'click', 'document.location.href = addNewLink');

        OW::getDocument()->addOnloadScript($js);
    }

    public function links() {
        $allFeeds = ADMINWIDGETS_BOL_Service::getInstance()->getAllLinks();

        $feedDetails = array();

        foreach ($allFeeds as $feed) {
            $id = $feed['id'];
            $feedDetails[$id]['id'] = $feed['id'];
            $feedDetails[$id]['linkUrl'] = $feed['url'];
            $feedDetails[$id]['linkText'] = $feed['text'];
            $feedDetails[$id]['linkSection'] = $feed['section'];
            $feedDetails[$id]['linkSectionName'] = $feed['name'];

            $feedDetails[$id]['editUrl'] = OW::getRouter()->urlForRoute('adminwidgets_admin_link_edit', array('id' => $id));
            $feedDetails[$id]['deleteUrl'] = OW::getRouter()->urlFor(__CLASS__, 'deletelink', array('id' => $id));
        }
        $this->assign('feedDetails', $feedDetails);

        $js = UTIL_JsGenerator::newInstance()
                ->newVariable('addNewLink', OW::getRouter()->urlForRoute('adminwidgets_admin_link_add'))
                ->jQueryEvent('#btn-add-new-link', 'click', 'document.location.href = addNewLink');

        OW::getDocument()->addOnloadScript($js);
    }

    public function sectionAdd() {

        $el = $this->menu->getElement('sections');
        if ($el) {
            $el->setActive(true);
        }

        $adminForm = new Form('adminForm');

        $language = OW::getLanguage();

        $element = new TextField('column');
        $element->setRequired(true);
        $element->setLabel($language->text('adminwidgets', 'menu_column_number'));
        $element->addValidator(new IntValidator());
        $adminForm->addElement($element);

        $element = new TextField('name');
        $element->setRequired(true);
        $element->setLabel($language->text('adminwidgets', 'menu_column_name'));
        $adminForm->addElement($element);

        $element = new Submit('addSection');
        $element->setValue($language->text('adminwidgets', 'admin_save_section'));
        $adminForm->addElement($element);

        $element = new Submit('addSectionAddNew');
        $element->setValue($language->text('adminwidgets', 'admin_save_add_section'));
        $adminForm->addElement($element);

        if (OW::getRequest()->isPost()) {
            if ($adminForm->isValid($_POST)) {
                $values = $adminForm->getValues();

                $section = new ADMINWIDGETS_BOL_Section();

                $section->section = $values['column'];
                $section->name = $values['name'];

                if (ADMINWIDGETS_BOL_Service::getInstance()->saveSection($section)) {
                    OW::getFeedback()->info($language->text('adminwidgets', 'admin_save_success'));

                    if (isset($_POST['addSection'])) {
                        $this->redirect(OW::getRouter()->urlForRoute('adminwidgets_admin_sections'));
                    } else {
                        $this->redirect(OW::getRouter()->urlForRoute('adminwidgets_admin_section_add'));
                    }
                }
            }
        }

        $this->addForm($adminForm);
    }

    public function sectionEdit($params) {
        if (!isset($params['id']) || !($id = (int) $params['id'])) {
            throw new Redirect404Exception();
            return;
        }

        $section = ADMINWIDGETS_BOL_Service::getInstance()->findSectionById($id);

        if (!$section) {
            throw new Redirect404Exception();
            return;
        }

        $el = $this->menu->getElement('sections');
        if ($el) {
            $el->setActive(true);
        }

        $oldSection = $section->section;

        $adminForm = new Form('adminForm');

        $language = OW::getLanguage();

        $element = new TextField('section');
        $element->setRequired(true);
        $element->setLabel($language->text('adminwidgets', 'menu_column_number'));
        $element->addValidator(new IntValidator());
        $element->setValue($section->section);
        $adminForm->addElement($element);

        $element = new TextField('name');
        $element->setRequired(true);
        $element->setLabel($language->text('adminwidgets', 'menu_column_name'));
        $element->setValue($section->name);
        $adminForm->addElement($element);

        $element = new Submit('editSection');
        $element->setValue($language->text('adminwidgets', 'admin_edit_section'));
        $adminForm->addElement($element);

        if (OW::getRequest()->isPost()) {
            if ($adminForm->isValid($_POST)) {
                $values = $adminForm->getValues();

                $section->section = $values['section'];
                $section->name = $values['name'];

                if (ADMINWIDGETS_BOL_Service::getInstance()->saveSection($section)) {
                    if ($oldSection != $values['section']) {
                        $sql = "UPDATE `" . ADMINWIDGETS_BOL_LinkDao::getInstance()->getTableName() . "` SET `section` = :newSection WHERE `section` = :oldSection";
                        OW::getDbo()->query($sql, array('oldSection' => $oldSection, 'newSection' => $values['section']));
                    }
                    OW::getFeedback()->info($language->text('adminwidgets', 'admin_edit_success'));

                    $this->redirect(OW::getRouter()->urlForRoute('adminwidgets_admin_sections'));
                }
            }
        }

        $this->addForm($adminForm);
    }

    public function linkEdit($params) {
        if (!isset($params['id']) || !($id = (int) $params['id'])) {
            throw new Redirect404Exception();
            return;
        }

        $link = ADMINWIDGETS_BOL_Service::getInstance()->findLinkById($id);

        if (!$link) {
            throw new Redirect404Exception();
            return;
        }

        $el = $this->menu->getElement('links');
        if ($el) {
            $el->setActive(true);
        }

        $adminForm = new Form('adminForm');

        $language = OW::getLanguage();

        $element = new TextField('url');
        $element->setRequired(true);
        $element->setLabel($language->text('adminwidgets', 'menu_url'));
        $element->setValue($link->url);
        $element->addValidator(new UrlValidator());
        $adminForm->addElement($element);

        $element = new TextField('text');
        $element->setRequired(true);
        $element->setLabel($language->text('adminwidgets', 'menu_text'));
        $element->setValue($link->text);
        $adminForm->addElement($element);

        $allSections = ADMINWIDGETS_BOL_Service::getInstance()->getAllSections();

        $element = new Selectbox('section');
        $element->setRequired(true);
        $element->setLabel($language->text('adminwidgets', 'menu_column_name'));
        $element->setValue($link->section);
        foreach ($allSections as $section) {
            $element->addOption($section->section, $section->name);
        }
        $adminForm->addElement($element);

        $element = new Submit('editLink');
        $element->setValue($language->text('adminwidgets', 'admin_edit_link'));
        $adminForm->addElement($element);

        if (OW::getRequest()->isPost()) {
            if ($adminForm->isValid($_POST)) {
                $values = $adminForm->getValues();

                $link->url = $values['url'];
                $link->text = $values['text'];
                $link->private = 0;
                $link->section = $values['section'];
                $link->timestamp = time();

                if (ADMINWIDGETS_BOL_Service::getInstance()->saveLink($link)) {
                    OW::getFeedback()->info($language->text('adminwidgets', 'admin_edit_success'));

                    $this->redirect(OW::getRouter()->urlForRoute('adminwidgets_admin_links'));
                }
            }
        }

        $this->addForm($adminForm);
    }

    public function linkAdd() {
        $el = $this->menu->getElement('links');
        if ($el) {
            $el->setActive(true);
        }

        $adminForm = new Form('adminForm');

        $language = OW::getLanguage();

        $element = new TextField('url');
        $element->setRequired(true);
        $element->setLabel($language->text('adminwidgets', 'menu_url'));
        $element->addValidator(new UrlValidator());
        $adminForm->addElement($element);

        $element = new TextField('text');
        $element->setRequired(true);
        $element->setLabel($language->text('adminwidgets', 'menu_text'));
        $adminForm->addElement($element);

        $allSections = ADMINWIDGETS_BOL_Service::getInstance()->getAllSections();

        $element = new Selectbox('section');
        $element->setRequired(true);
        $element->setLabel($language->text('adminwidgets', 'menu_column_name'));
        foreach ($allSections as $section) {
            $element->addOption($section->section, $section->name);
        }
        $adminForm->addElement($element);

        $element = new Submit('addLink');
        $element->setValue($language->text('adminwidgets', 'admin_save_link'));
        $adminForm->addElement($element);

        $element = new Submit('addLinkAddNew');
        $element->setValue($language->text('adminwidgets', 'admin_save_add_link'));
        $adminForm->addElement($element);

        if (OW::getRequest()->isPost()) {
            if ($adminForm->isValid($_POST)) {
                $values = $adminForm->getValues();

                $link = new ADMINWIDGETS_BOL_Link();

                $link->url = $values['url'];
                $link->text = $values['text'];
                $link->private = 0;
                $link->section = $values['section'];
                $link->timestamp = time();

                if (ADMINWIDGETS_BOL_Service::getInstance()->saveLink($link)) {
                    OW::getFeedback()->info($language->text('adminwidgets', 'admin_save_success'));

                    if (isset($_POST['addLink'])) {
                        $this->redirect(OW::getRouter()->urlForRoute('adminwidgets_admin_links'));
                    } else {
                        $this->redirect(OW::getRouter()->urlForRoute('adminwidgets_admin_link_add'));
                    }
                }
            }
        }

        $this->addForm($adminForm);
    }

    public function deletelink($params) {
        if (isset($params['id'])) {
            ADMINWIDGETS_BOL_Service::getInstance()->deleteLink((int) $params['id']);
            OW::getFeedback()->info(OW::getLanguage()->text('adminwidgets', 'admin_delete_success'));
        }
        $this->redirect(OW::getRouter()->urlForRoute('adminwidgets_admin_links'));
    }

    public function deletesection($params) {
        if (isset($params['column']) && (int) $params['column'] > 1) {
            ADMINWIDGETS_BOL_Service::getInstance()->deleteSection((int) $params['column']);
            OW::getFeedback()->info(OW::getLanguage()->text('adminwidgets', 'admin_delete_success'));
        }
        $this->redirect(OW::getRouter()->urlForRoute('adminwidgets_admin_sections'));
    }

}